#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-ECD3GQutx07JzA2jVSeB0I
key:                  haskell-language-server-2.3.0.0-ECD3GQutx07JzA2jVSeB0I
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  60390c71e8be9eb11d6371bd8c14c0e7
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-ECD3GQutx07JzA2jVSeB0I
depends:
    aeson-pretty-0.8.10-EYHzIte6KbSLrMzV6qr2Uj
    async-2.2.6-6oBfo7va0Nh7ISraaAL0Gg base-4.18.2.1
    base16-bytestring-1.0.2.0-AGwhh1Ev3mPCOOC4X0N9yh
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-3CAmO8Hny3b1HSdOxK3bZ1
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-9HJWsKGqeQNGNK4b68nPpp filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-Bfg1eWqKv2P9EhjAubTTO0
    githash-0.1.7.0-IgGwKGrQ4YIHcrgiB8Eydr
    hie-bios-0.12.0-6tUdn1Fsgvi590kFgkPIkA
    hiedb-0.4.3.0-FCENXTmXwkbCHsjfoD9dSI
    hls-alternate-number-format-plugin-2.3.0.0-BzTqLQuKj4gHk81la0D8vQ
    hls-cabal-fmt-plugin-2.3.0.0-2PYX7i6kCeSGw7v3rx407S
    hls-cabal-plugin-2.3.0.0-IgwbTbA7DB76bOIvt1nl1u
    hls-call-hierarchy-plugin-2.3.0.0-FpoHkI1caZ86NbCP1tIysN
    hls-change-type-signature-plugin-2.3.0.0-E6qJXr354lyJEvcinbj61a
    hls-class-plugin-2.3.0.0-JmJ3gsYVkSII6rwxkYHufw
    hls-code-range-plugin-2.3.0.0-J0U5Z06998D6TXPlUyDKJB
    hls-eval-plugin-2.3.0.0-IMNRBXTiUdFEasgmtnF8GB
    hls-explicit-fixity-plugin-2.3.0.0-Qe30J99CeE7YLmCPj3GKt
    hls-explicit-imports-plugin-2.3.0.0-2IJHxNcH0RSJG09Paz6C9b
    hls-explicit-record-fields-plugin-2.3.0.0-KLb63mhBJL4RHQNGD4ADU
    hls-fourmolu-plugin-2.3.0.0-GSAzpahDUwtCLtcXvKcYdI
    hls-gadt-plugin-2.3.0.0-BjC11GT0o2GH9Tat5EfgN2
    hls-graph-2.3.0.0-6ya4aMOTgUBOHsm6cIh9H
    hls-hlint-plugin-2.3.0.0-8Yl2sMYcWknCZC3Hd0WX1H
    hls-module-name-plugin-2.3.0.0-Hf6Wa7M5x6vLTKrzGjGDfZ
    hls-ormolu-plugin-2.3.0.0-FT77HAqDoIXLjYdo7PSf1d
    hls-overloaded-record-dot-plugin-2.3.0.0-KIP6Ctiwkx92Veuxcshquc
    hls-plugin-api-2.3.0.0-2cVMP2AJp9EB89sXuyaAt3
    hls-pragmas-plugin-2.3.0.0-Cx3QeJQzrWgDsbT2g5c66O
    hls-qualify-imported-names-plugin-2.3.0.0-DsdaDlioEISGRDHbt51MaM
    hls-refactor-plugin-2.3.0.0-G8XojnaKoxvI5XCS3WShcB
    hls-rename-plugin-2.3.0.0-J5fMYNmrdH7vIunfGAF4G
    hls-retrie-plugin-2.3.0.0-AiWCBBqgoliHSfuX6YReiD
    hls-splice-plugin-2.3.0.0-KIijpd50sFVJeyhb0aGOqb
    hls-stylish-haskell-plugin-2.3.0.0-8wZ4M8y5oTKA1KpbrXGyKh
    lsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk
    optparse-applicative-0.18.1.0-2Hiadv6BpzgDgx5QxnTvo5
    optparse-simple-0.1.1.4-LGgaqOr3Gij2JvJpwBNCVm
    prettyprinter-1.7.1-1xxpbQWBfCkKy2RpQWmuRC process-1.6.19.0
    safe-exceptions-0.1.7.4-E8bKL7uaaVw8oJ8z17Leck
    sqlite-simple-0.4.19.0-6CU2daHMT0O8cZviSdsvd2 text-2.0.2
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

